# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetClbResult',
    'AwaitableGetClbResult',
    'get_clb',
    'get_clb_output',
]

@pulumi.output_type
class GetClbResult:
    """
    A collection of values returned by getClb.
    """
    def __init__(__self__, access_log=None, account_id=None, address_ip_version=None, allowed_ports=None, auto_renewal=None, business_status=None, bypass_security_group_enabled=None, create_time=None, deleted_time=None, description=None, eip=None, eip_address=None, eip_id=None, enabled=None, eni=None, eni_address_num=None, eni_ipv6_address=None, enis=None, exclusive_cluster_id=None, expired_time=None, id=None, listeners=None, load_balancer_billing_type=None, load_balancer_id=None, load_balancer_name=None, load_balancer_spec=None, lock_reason=None, master_zone_id=None, modification_protection_reason=None, modification_protection_status=None, new_arch=None, order_id=None, overdue_time=None, period=None, period_unit=None, project_name=None, server_groups=None, service_managed=None, slave_zone_id=None, status=None, subnet_id=None, tags=None, timestamp_remove_enabled=None, type=None, update_time=None, vpc_id=None, zone_type=None):
        if access_log and not isinstance(access_log, dict):
            raise TypeError("Expected argument 'access_log' to be a dict")
        pulumi.set(__self__, "access_log", access_log)
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if address_ip_version and not isinstance(address_ip_version, str):
            raise TypeError("Expected argument 'address_ip_version' to be a str")
        pulumi.set(__self__, "address_ip_version", address_ip_version)
        if allowed_ports and not isinstance(allowed_ports, list):
            raise TypeError("Expected argument 'allowed_ports' to be a list")
        pulumi.set(__self__, "allowed_ports", allowed_ports)
        if auto_renewal and not isinstance(auto_renewal, bool):
            raise TypeError("Expected argument 'auto_renewal' to be a bool")
        pulumi.set(__self__, "auto_renewal", auto_renewal)
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if bypass_security_group_enabled and not isinstance(bypass_security_group_enabled, str):
            raise TypeError("Expected argument 'bypass_security_group_enabled' to be a str")
        pulumi.set(__self__, "bypass_security_group_enabled", bypass_security_group_enabled)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if deleted_time and not isinstance(deleted_time, str):
            raise TypeError("Expected argument 'deleted_time' to be a str")
        pulumi.set(__self__, "deleted_time", deleted_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if eip and not isinstance(eip, dict):
            raise TypeError("Expected argument 'eip' to be a dict")
        pulumi.set(__self__, "eip", eip)
        if eip_address and not isinstance(eip_address, str):
            raise TypeError("Expected argument 'eip_address' to be a str")
        pulumi.set(__self__, "eip_address", eip_address)
        if eip_id and not isinstance(eip_id, str):
            raise TypeError("Expected argument 'eip_id' to be a str")
        pulumi.set(__self__, "eip_id", eip_id)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if eni and not isinstance(eni, dict):
            raise TypeError("Expected argument 'eni' to be a dict")
        pulumi.set(__self__, "eni", eni)
        if eni_address_num and not isinstance(eni_address_num, float):
            raise TypeError("Expected argument 'eni_address_num' to be a float")
        pulumi.set(__self__, "eni_address_num", eni_address_num)
        if eni_ipv6_address and not isinstance(eni_ipv6_address, str):
            raise TypeError("Expected argument 'eni_ipv6_address' to be a str")
        pulumi.set(__self__, "eni_ipv6_address", eni_ipv6_address)
        if enis and not isinstance(enis, dict):
            raise TypeError("Expected argument 'enis' to be a dict")
        pulumi.set(__self__, "enis", enis)
        if exclusive_cluster_id and not isinstance(exclusive_cluster_id, str):
            raise TypeError("Expected argument 'exclusive_cluster_id' to be a str")
        pulumi.set(__self__, "exclusive_cluster_id", exclusive_cluster_id)
        if expired_time and not isinstance(expired_time, str):
            raise TypeError("Expected argument 'expired_time' to be a str")
        pulumi.set(__self__, "expired_time", expired_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if listeners and not isinstance(listeners, list):
            raise TypeError("Expected argument 'listeners' to be a list")
        pulumi.set(__self__, "listeners", listeners)
        if load_balancer_billing_type and not isinstance(load_balancer_billing_type, float):
            raise TypeError("Expected argument 'load_balancer_billing_type' to be a float")
        pulumi.set(__self__, "load_balancer_billing_type", load_balancer_billing_type)
        if load_balancer_id and not isinstance(load_balancer_id, str):
            raise TypeError("Expected argument 'load_balancer_id' to be a str")
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if load_balancer_name and not isinstance(load_balancer_name, str):
            raise TypeError("Expected argument 'load_balancer_name' to be a str")
        pulumi.set(__self__, "load_balancer_name", load_balancer_name)
        if load_balancer_spec and not isinstance(load_balancer_spec, str):
            raise TypeError("Expected argument 'load_balancer_spec' to be a str")
        pulumi.set(__self__, "load_balancer_spec", load_balancer_spec)
        if lock_reason and not isinstance(lock_reason, str):
            raise TypeError("Expected argument 'lock_reason' to be a str")
        pulumi.set(__self__, "lock_reason", lock_reason)
        if master_zone_id and not isinstance(master_zone_id, str):
            raise TypeError("Expected argument 'master_zone_id' to be a str")
        pulumi.set(__self__, "master_zone_id", master_zone_id)
        if modification_protection_reason and not isinstance(modification_protection_reason, str):
            raise TypeError("Expected argument 'modification_protection_reason' to be a str")
        pulumi.set(__self__, "modification_protection_reason", modification_protection_reason)
        if modification_protection_status and not isinstance(modification_protection_status, str):
            raise TypeError("Expected argument 'modification_protection_status' to be a str")
        pulumi.set(__self__, "modification_protection_status", modification_protection_status)
        if new_arch and not isinstance(new_arch, bool):
            raise TypeError("Expected argument 'new_arch' to be a bool")
        pulumi.set(__self__, "new_arch", new_arch)
        if order_id and not isinstance(order_id, str):
            raise TypeError("Expected argument 'order_id' to be a str")
        pulumi.set(__self__, "order_id", order_id)
        if overdue_time and not isinstance(overdue_time, str):
            raise TypeError("Expected argument 'overdue_time' to be a str")
        pulumi.set(__self__, "overdue_time", overdue_time)
        if period and not isinstance(period, float):
            raise TypeError("Expected argument 'period' to be a float")
        pulumi.set(__self__, "period", period)
        if period_unit and not isinstance(period_unit, str):
            raise TypeError("Expected argument 'period_unit' to be a str")
        pulumi.set(__self__, "period_unit", period_unit)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if server_groups and not isinstance(server_groups, list):
            raise TypeError("Expected argument 'server_groups' to be a list")
        pulumi.set(__self__, "server_groups", server_groups)
        if service_managed and not isinstance(service_managed, bool):
            raise TypeError("Expected argument 'service_managed' to be a bool")
        pulumi.set(__self__, "service_managed", service_managed)
        if slave_zone_id and not isinstance(slave_zone_id, str):
            raise TypeError("Expected argument 'slave_zone_id' to be a str")
        pulumi.set(__self__, "slave_zone_id", slave_zone_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if timestamp_remove_enabled and not isinstance(timestamp_remove_enabled, str):
            raise TypeError("Expected argument 'timestamp_remove_enabled' to be a str")
        pulumi.set(__self__, "timestamp_remove_enabled", timestamp_remove_enabled)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_type and not isinstance(zone_type, str):
            raise TypeError("Expected argument 'zone_type' to be a str")
        pulumi.set(__self__, "zone_type", zone_type)

    @property
    @pulumi.getter(name="accessLog")
    def access_log(self) -> 'outputs.GetClbAccessLogResult':
        """
        负载均衡实例中访问日志的信息。
        """
        return pulumi.get(self, "access_log")

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        负载均衡实例所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> builtins.str:
        """
        CLB实例的IP地址类型。取值如下：ipv4（默认值）：表示该CLB为IPv4类型，仅支持转发IPv4请求。DualStack：表示该CLB为双栈类型，支持转发IPv4和IPv6请求。仅参数Type取private时，才可传入DualStack。
        """
        return pulumi.get(self, "address_ip_version")

    @property
    @pulumi.getter(name="allowedPorts")
    def allowed_ports(self) -> Sequence[builtins.str]:
        """
        允许的多个端口范围。
        """
        return pulumi.get(self, "allowed_ports")

    @property
    @pulumi.getter(name="autoRenewal")
    def auto_renewal(self) -> builtins.bool:
        """
        是否开通自动续费。true：是，默认自动续费为1个月。false（默认值）：否
        """
        return pulumi.get(self, "auto_renewal")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        负载均衡实例是否被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="bypassSecurityGroupEnabled")
    def bypass_security_group_enabled(self) -> builtins.str:
        """
        是否开启bypass安全组功能。
        """
        return pulumi.get(self, "bypass_security_group_enabled")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        负载均衡实例的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> builtins.str:
        """
        负载均衡实例的预期回收时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        负载均衡实例的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def eip(self) -> 'outputs.GetClbEipResult':
        """
        负载均衡实例的公网IP的信息。
        """
        return pulumi.get(self, "eip")

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> builtins.str:
        """
        公网IP地址。
        """
        return pulumi.get(self, "eip_address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> builtins.str:
        """
        公网IP ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        负载均衡实例的启用状态。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def eni(self) -> 'outputs.GetClbEniResult':
        """
        负载均衡实例的私网IPv4地址信息。
        """
        return pulumi.get(self, "eni")

    @property
    @pulumi.getter(name="eniAddressNum")
    def eni_address_num(self) -> builtins.float:
        """
        负载均衡实例的私网IPv4地址数量。该参数和参数EniAddress不能同时传入，如果传入该参数，则无需传入EniAddress。
        """
        return pulumi.get(self, "eni_address_num")

    @property
    @pulumi.getter(name="eniIpv6Address")
    def eni_ipv6_address(self) -> builtins.str:
        """
        负载均衡实例的私网IPv6地址。
        """
        return pulumi.get(self, "eni_ipv6_address")

    @property
    @pulumi.getter
    def enis(self) -> 'outputs.GetClbEnisResult':
        """
        负载均衡实例的私网IPv4地址信息列表，创建时通过EniAddressNum指定数量。
        """
        return pulumi.get(self, "enis")

    @property
    @pulumi.getter(name="exclusiveClusterId")
    def exclusive_cluster_id(self) -> builtins.str:
        """
        独占集群Id。
        """
        return pulumi.get(self, "exclusive_cluster_id")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> builtins.str:
        """
        负载均衡实例到期时间。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def listeners(self) -> Sequence['outputs.GetClbListenerResult']:
        """
        负载均衡实例中监听器的信息。
        """
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="loadBalancerBillingType")
    def load_balancer_billing_type(self) -> builtins.float:
        """
        CLB实例计费方式。取值如下：1：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。
        """
        return pulumi.get(self, "load_balancer_billing_type")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> builtins.str:
        """
        负载均衡实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="loadBalancerName")
    def load_balancer_name(self) -> builtins.str:
        """
        负载均衡实例的名称。
        """
        return pulumi.get(self, "load_balancer_name")

    @property
    @pulumi.getter(name="loadBalancerSpec")
    def load_balancer_spec(self) -> builtins.str:
        """
        CLB实例的规格，不同规格提供的转发能力不同。small*1：小型I。small*2：小型II。medium*1：中型I。medium*2：中型II。large*1：大型I。large*2：大型II。
        """
        return pulumi.get(self, "load_balancer_spec")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        """
        负载均衡实例被冻结的原因。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="masterZoneId")
    def master_zone_id(self) -> builtins.str:
        """
        负载均衡实例的主可用区ID。
        """
        return pulumi.get(self, "master_zone_id")

    @property
    @pulumi.getter(name="modificationProtectionReason")
    def modification_protection_reason(self) -> builtins.str:
        """
        设置修改保护状态的原因。仅参数ModificationProtectionStatus取ConsoleProtection时，本参数有效。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：半角句号（.）、下划线（_）和中划线（-）。长度限制为1 ～ 80个字符。
        """
        return pulumi.get(self, "modification_protection_reason")

    @property
    @pulumi.getter(name="modificationProtectionStatus")
    def modification_protection_status(self) -> builtins.str:
        """
        CLB实例是否开启控制台上修改保护。开启后，禁止通过控制台修改实例或删除实例。取值如下：NonProtection：不开启。ConsoleProtection：开启。
        """
        return pulumi.get(self, "modification_protection_status")

    @property
    @pulumi.getter(name="newArch")
    def new_arch(self) -> builtins.bool:
        """
        是否为新架构。
        """
        return pulumi.get(self, "new_arch")

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> builtins.str:
        """
        订单ID。仅在创建动作的参数LoadBalancerBillingType配置为1时，该参数有值。
        """
        return pulumi.get(self, "order_id")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> builtins.str:
        """
        负载均衡实例的冻结时间。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter
    def period(self) -> builtins.float:
        """
        购买包年包月CLB实例的时长。默认为“1”。当PeriodUnit配置为Month时，取值范围为1～9，12，24和36。当PeriodUnit配置为Year时，取值范围为1～3。
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> builtins.str:
        """
        购买包年包月CLB实例的时长单位。仅LoadBalancerBillingType取1时，本参数有效。取值如下：Month (默认值)：月。Year：年
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        CLB实例所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="serverGroups")
    def server_groups(self) -> Sequence['outputs.GetClbServerGroupResult']:
        """
        负载均衡实例中后端服务器组的信息。
        """
        return pulumi.get(self, "server_groups")

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> builtins.bool:
        """
        CLB实例是否为托管资源。
        """
        return pulumi.get(self, "service_managed")

    @property
    @pulumi.getter(name="slaveZoneId")
    def slave_zone_id(self) -> builtins.str:
        """
        负载均衡实例的备可用区ID。
        """
        return pulumi.get(self, "slave_zone_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        负载均衡实例状态，Inactive：已停止。Active：运行中。Creating：创建中。Provisioning：创建中。Configuring：配置中。Deleting：删除中。CreateFailed：创建失败。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        负载均衡实例所属VPC内的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetClbTagResult']:
        """
        CLB实例标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="timestampRemoveEnabled")
    def timestamp_remove_enabled(self) -> builtins.str:
        """
        是否开启 TCP Timestamp 清除功能。
        """
        return pulumi.get(self, "timestamp_remove_enabled")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        CLB实例的类型。取值如下：public：公网类型。创建一个公网类型CLB实例，系统会分配一个公网IP地址，用于转发公网请求。private：私网类型。创建一个私网类型CLB实例，您需要为其绑定公网IP后，才能转发公网请求。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        负载均衡实例的最近操作时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        负载均衡实例所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneType")
    def zone_type(self) -> builtins.str:
        """
        负载均衡实例的可用区类型。
        """
        return pulumi.get(self, "zone_type")


class AwaitableGetClbResult(GetClbResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClbResult(
            access_log=self.access_log,
            account_id=self.account_id,
            address_ip_version=self.address_ip_version,
            allowed_ports=self.allowed_ports,
            auto_renewal=self.auto_renewal,
            business_status=self.business_status,
            bypass_security_group_enabled=self.bypass_security_group_enabled,
            create_time=self.create_time,
            deleted_time=self.deleted_time,
            description=self.description,
            eip=self.eip,
            eip_address=self.eip_address,
            eip_id=self.eip_id,
            enabled=self.enabled,
            eni=self.eni,
            eni_address_num=self.eni_address_num,
            eni_ipv6_address=self.eni_ipv6_address,
            enis=self.enis,
            exclusive_cluster_id=self.exclusive_cluster_id,
            expired_time=self.expired_time,
            id=self.id,
            listeners=self.listeners,
            load_balancer_billing_type=self.load_balancer_billing_type,
            load_balancer_id=self.load_balancer_id,
            load_balancer_name=self.load_balancer_name,
            load_balancer_spec=self.load_balancer_spec,
            lock_reason=self.lock_reason,
            master_zone_id=self.master_zone_id,
            modification_protection_reason=self.modification_protection_reason,
            modification_protection_status=self.modification_protection_status,
            new_arch=self.new_arch,
            order_id=self.order_id,
            overdue_time=self.overdue_time,
            period=self.period,
            period_unit=self.period_unit,
            project_name=self.project_name,
            server_groups=self.server_groups,
            service_managed=self.service_managed,
            slave_zone_id=self.slave_zone_id,
            status=self.status,
            subnet_id=self.subnet_id,
            tags=self.tags,
            timestamp_remove_enabled=self.timestamp_remove_enabled,
            type=self.type,
            update_time=self.update_time,
            vpc_id=self.vpc_id,
            zone_type=self.zone_type)


def get_clb(id: Optional[builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClbResult:
    """
    Data Source schema for Byteplus::CLB::CLB


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:clb/getClb:getClb', __args__, opts=opts, typ=GetClbResult).value

    return AwaitableGetClbResult(
        access_log=pulumi.get(__ret__, 'access_log'),
        account_id=pulumi.get(__ret__, 'account_id'),
        address_ip_version=pulumi.get(__ret__, 'address_ip_version'),
        allowed_ports=pulumi.get(__ret__, 'allowed_ports'),
        auto_renewal=pulumi.get(__ret__, 'auto_renewal'),
        business_status=pulumi.get(__ret__, 'business_status'),
        bypass_security_group_enabled=pulumi.get(__ret__, 'bypass_security_group_enabled'),
        create_time=pulumi.get(__ret__, 'create_time'),
        deleted_time=pulumi.get(__ret__, 'deleted_time'),
        description=pulumi.get(__ret__, 'description'),
        eip=pulumi.get(__ret__, 'eip'),
        eip_address=pulumi.get(__ret__, 'eip_address'),
        eip_id=pulumi.get(__ret__, 'eip_id'),
        enabled=pulumi.get(__ret__, 'enabled'),
        eni=pulumi.get(__ret__, 'eni'),
        eni_address_num=pulumi.get(__ret__, 'eni_address_num'),
        eni_ipv6_address=pulumi.get(__ret__, 'eni_ipv6_address'),
        enis=pulumi.get(__ret__, 'enis'),
        exclusive_cluster_id=pulumi.get(__ret__, 'exclusive_cluster_id'),
        expired_time=pulumi.get(__ret__, 'expired_time'),
        id=pulumi.get(__ret__, 'id'),
        listeners=pulumi.get(__ret__, 'listeners'),
        load_balancer_billing_type=pulumi.get(__ret__, 'load_balancer_billing_type'),
        load_balancer_id=pulumi.get(__ret__, 'load_balancer_id'),
        load_balancer_name=pulumi.get(__ret__, 'load_balancer_name'),
        load_balancer_spec=pulumi.get(__ret__, 'load_balancer_spec'),
        lock_reason=pulumi.get(__ret__, 'lock_reason'),
        master_zone_id=pulumi.get(__ret__, 'master_zone_id'),
        modification_protection_reason=pulumi.get(__ret__, 'modification_protection_reason'),
        modification_protection_status=pulumi.get(__ret__, 'modification_protection_status'),
        new_arch=pulumi.get(__ret__, 'new_arch'),
        order_id=pulumi.get(__ret__, 'order_id'),
        overdue_time=pulumi.get(__ret__, 'overdue_time'),
        period=pulumi.get(__ret__, 'period'),
        period_unit=pulumi.get(__ret__, 'period_unit'),
        project_name=pulumi.get(__ret__, 'project_name'),
        server_groups=pulumi.get(__ret__, 'server_groups'),
        service_managed=pulumi.get(__ret__, 'service_managed'),
        slave_zone_id=pulumi.get(__ret__, 'slave_zone_id'),
        status=pulumi.get(__ret__, 'status'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        tags=pulumi.get(__ret__, 'tags'),
        timestamp_remove_enabled=pulumi.get(__ret__, 'timestamp_remove_enabled'),
        type=pulumi.get(__ret__, 'type'),
        update_time=pulumi.get(__ret__, 'update_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        zone_type=pulumi.get(__ret__, 'zone_type'))
def get_clb_output(id: Optional[pulumi.Input[builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetClbResult]:
    """
    Data Source schema for Byteplus::CLB::CLB


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:clb/getClb:getClb', __args__, opts=opts, typ=GetClbResult)
    return __ret__.apply(lambda __response__: GetClbResult(
        access_log=pulumi.get(__response__, 'access_log'),
        account_id=pulumi.get(__response__, 'account_id'),
        address_ip_version=pulumi.get(__response__, 'address_ip_version'),
        allowed_ports=pulumi.get(__response__, 'allowed_ports'),
        auto_renewal=pulumi.get(__response__, 'auto_renewal'),
        business_status=pulumi.get(__response__, 'business_status'),
        bypass_security_group_enabled=pulumi.get(__response__, 'bypass_security_group_enabled'),
        create_time=pulumi.get(__response__, 'create_time'),
        deleted_time=pulumi.get(__response__, 'deleted_time'),
        description=pulumi.get(__response__, 'description'),
        eip=pulumi.get(__response__, 'eip'),
        eip_address=pulumi.get(__response__, 'eip_address'),
        eip_id=pulumi.get(__response__, 'eip_id'),
        enabled=pulumi.get(__response__, 'enabled'),
        eni=pulumi.get(__response__, 'eni'),
        eni_address_num=pulumi.get(__response__, 'eni_address_num'),
        eni_ipv6_address=pulumi.get(__response__, 'eni_ipv6_address'),
        enis=pulumi.get(__response__, 'enis'),
        exclusive_cluster_id=pulumi.get(__response__, 'exclusive_cluster_id'),
        expired_time=pulumi.get(__response__, 'expired_time'),
        id=pulumi.get(__response__, 'id'),
        listeners=pulumi.get(__response__, 'listeners'),
        load_balancer_billing_type=pulumi.get(__response__, 'load_balancer_billing_type'),
        load_balancer_id=pulumi.get(__response__, 'load_balancer_id'),
        load_balancer_name=pulumi.get(__response__, 'load_balancer_name'),
        load_balancer_spec=pulumi.get(__response__, 'load_balancer_spec'),
        lock_reason=pulumi.get(__response__, 'lock_reason'),
        master_zone_id=pulumi.get(__response__, 'master_zone_id'),
        modification_protection_reason=pulumi.get(__response__, 'modification_protection_reason'),
        modification_protection_status=pulumi.get(__response__, 'modification_protection_status'),
        new_arch=pulumi.get(__response__, 'new_arch'),
        order_id=pulumi.get(__response__, 'order_id'),
        overdue_time=pulumi.get(__response__, 'overdue_time'),
        period=pulumi.get(__response__, 'period'),
        period_unit=pulumi.get(__response__, 'period_unit'),
        project_name=pulumi.get(__response__, 'project_name'),
        server_groups=pulumi.get(__response__, 'server_groups'),
        service_managed=pulumi.get(__response__, 'service_managed'),
        slave_zone_id=pulumi.get(__response__, 'slave_zone_id'),
        status=pulumi.get(__response__, 'status'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        tags=pulumi.get(__response__, 'tags'),
        timestamp_remove_enabled=pulumi.get(__response__, 'timestamp_remove_enabled'),
        type=pulumi.get(__response__, 'type'),
        update_time=pulumi.get(__response__, 'update_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        zone_type=pulumi.get(__response__, 'zone_type')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetFlowLogResult',
    'AwaitableGetFlowLogResult',
    'get_flow_log',
    'get_flow_log_output',
]

@pulumi.output_type
class GetFlowLogResult:
    """
    A collection of values returned by getFlowLog.
    """
    def __init__(__self__, aggregation_interval=None, business_status=None, created_at=None, description=None, enable_index=None, flow_log_id=None, flow_log_name=None, id=None, lock_reason=None, log_project_id=None, log_project_name=None, log_topic_id=None, log_topic_name=None, project_name=None, resource_id=None, resource_type=None, status=None, tags=None, traffic_type=None, updated_at=None, vpc_id=None):
        if aggregation_interval and not isinstance(aggregation_interval, int):
            raise TypeError("Expected argument 'aggregation_interval' to be a int")
        pulumi.set(__self__, "aggregation_interval", aggregation_interval)
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enable_index and not isinstance(enable_index, bool):
            raise TypeError("Expected argument 'enable_index' to be a bool")
        pulumi.set(__self__, "enable_index", enable_index)
        if flow_log_id and not isinstance(flow_log_id, str):
            raise TypeError("Expected argument 'flow_log_id' to be a str")
        pulumi.set(__self__, "flow_log_id", flow_log_id)
        if flow_log_name and not isinstance(flow_log_name, str):
            raise TypeError("Expected argument 'flow_log_name' to be a str")
        pulumi.set(__self__, "flow_log_name", flow_log_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lock_reason and not isinstance(lock_reason, str):
            raise TypeError("Expected argument 'lock_reason' to be a str")
        pulumi.set(__self__, "lock_reason", lock_reason)
        if log_project_id and not isinstance(log_project_id, str):
            raise TypeError("Expected argument 'log_project_id' to be a str")
        pulumi.set(__self__, "log_project_id", log_project_id)
        if log_project_name and not isinstance(log_project_name, str):
            raise TypeError("Expected argument 'log_project_name' to be a str")
        pulumi.set(__self__, "log_project_name", log_project_name)
        if log_topic_id and not isinstance(log_topic_id, str):
            raise TypeError("Expected argument 'log_topic_id' to be a str")
        pulumi.set(__self__, "log_topic_id", log_topic_id)
        if log_topic_name and not isinstance(log_topic_name, str):
            raise TypeError("Expected argument 'log_topic_name' to be a str")
        pulumi.set(__self__, "log_topic_name", log_topic_name)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        pulumi.set(__self__, "resource_id", resource_id)
        if resource_type and not isinstance(resource_type, str):
            raise TypeError("Expected argument 'resource_type' to be a str")
        pulumi.set(__self__, "resource_type", resource_type)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if traffic_type and not isinstance(traffic_type, str):
            raise TypeError("Expected argument 'traffic_type' to be a str")
        pulumi.set(__self__, "traffic_type", traffic_type)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="aggregationInterval")
    def aggregation_interval(self) -> builtins.int:
        """
        流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        """
        return pulumi.get(self, "aggregation_interval")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        流日志是否被锁定。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        流日志的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableIndex")
    def enable_index(self) -> builtins.bool:
        """
        是否自动配置索引。索引用于检索分析数据，流日志在检索分析之前，必须先配置索引。true：是。false（默认值）：否。
        """
        return pulumi.get(self, "enable_index")

    @property
    @pulumi.getter(name="flowLogId")
    def flow_log_id(self) -> builtins.str:
        """
        流日志的ID。
        """
        return pulumi.get(self, "flow_log_id")

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> builtins.str:
        """
        流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        """
        return pulumi.get(self, "flow_log_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        """
        流日志被锁定的原因。financial: 因欠费被锁定。unlock：欠费关停后充值恢复过程中。空值 : 没有被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="logProjectId")
    def log_project_id(self) -> builtins.str:
        """
        流日志项目的ID。
        """
        return pulumi.get(self, "log_project_id")

    @property
    @pulumi.getter(name="logProjectName")
    def log_project_name(self) -> builtins.str:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_project_name")

    @property
    @pulumi.getter(name="logTopicId")
    def log_topic_id(self) -> builtins.str:
        """
        流日志主题的ID。
        """
        return pulumi.get(self, "log_topic_id")

    @property
    @pulumi.getter(name="logTopicName")
    def log_topic_name(self) -> builtins.str:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_topic_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        流流日志所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> builtins.str:
        """
        要捕获流量的资源ID。
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> builtins.str:
        """
        要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetFlowLogTagResult']:
        """
        流日志的标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficType")
    def traffic_type(self) -> builtins.str:
        """
        采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        """
        return pulumi.get(self, "traffic_type")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        更新流日志的时间。
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        流日志的VPC的ID。
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetFlowLogResult(GetFlowLogResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFlowLogResult(
            aggregation_interval=self.aggregation_interval,
            business_status=self.business_status,
            created_at=self.created_at,
            description=self.description,
            enable_index=self.enable_index,
            flow_log_id=self.flow_log_id,
            flow_log_name=self.flow_log_name,
            id=self.id,
            lock_reason=self.lock_reason,
            log_project_id=self.log_project_id,
            log_project_name=self.log_project_name,
            log_topic_id=self.log_topic_id,
            log_topic_name=self.log_topic_name,
            project_name=self.project_name,
            resource_id=self.resource_id,
            resource_type=self.resource_type,
            status=self.status,
            tags=self.tags,
            traffic_type=self.traffic_type,
            updated_at=self.updated_at,
            vpc_id=self.vpc_id)


def get_flow_log(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFlowLogResult:
    """
    Data Source schema for Byteplus::VPC::FlowLog


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getFlowLog:getFlowLog', __args__, opts=opts, typ=GetFlowLogResult).value

    return AwaitableGetFlowLogResult(
        aggregation_interval=pulumi.get(__ret__, 'aggregation_interval'),
        business_status=pulumi.get(__ret__, 'business_status'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        enable_index=pulumi.get(__ret__, 'enable_index'),
        flow_log_id=pulumi.get(__ret__, 'flow_log_id'),
        flow_log_name=pulumi.get(__ret__, 'flow_log_name'),
        id=pulumi.get(__ret__, 'id'),
        lock_reason=pulumi.get(__ret__, 'lock_reason'),
        log_project_id=pulumi.get(__ret__, 'log_project_id'),
        log_project_name=pulumi.get(__ret__, 'log_project_name'),
        log_topic_id=pulumi.get(__ret__, 'log_topic_id'),
        log_topic_name=pulumi.get(__ret__, 'log_topic_name'),
        project_name=pulumi.get(__ret__, 'project_name'),
        resource_id=pulumi.get(__ret__, 'resource_id'),
        resource_type=pulumi.get(__ret__, 'resource_type'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        traffic_type=pulumi.get(__ret__, 'traffic_type'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_flow_log_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFlowLogResult]:
    """
    Data Source schema for Byteplus::VPC::FlowLog


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getFlowLog:getFlowLog', __args__, opts=opts, typ=GetFlowLogResult)
    return __ret__.apply(lambda __response__: GetFlowLogResult(
        aggregation_interval=pulumi.get(__response__, 'aggregation_interval'),
        business_status=pulumi.get(__response__, 'business_status'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        enable_index=pulumi.get(__response__, 'enable_index'),
        flow_log_id=pulumi.get(__response__, 'flow_log_id'),
        flow_log_name=pulumi.get(__response__, 'flow_log_name'),
        id=pulumi.get(__response__, 'id'),
        lock_reason=pulumi.get(__response__, 'lock_reason'),
        log_project_id=pulumi.get(__response__, 'log_project_id'),
        log_project_name=pulumi.get(__response__, 'log_project_name'),
        log_topic_id=pulumi.get(__response__, 'log_topic_id'),
        log_topic_name=pulumi.get(__response__, 'log_topic_name'),
        project_name=pulumi.get(__response__, 'project_name'),
        resource_id=pulumi.get(__response__, 'resource_id'),
        resource_type=pulumi.get(__response__, 'resource_type'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        traffic_type=pulumi.get(__response__, 'traffic_type'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HealthCheckTemplateArgs', 'HealthCheckTemplate']

@pulumi.input_type
class HealthCheckTemplateArgs:
    def __init__(__self__, *,
                 health_check_template_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_domain: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_http_code: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_http_version: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_interval: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_method: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_port: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_protocol: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_uri: Optional[pulumi.Input[builtins.str]] = None,
                 healthy_threshold: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['HealthCheckTemplateTagArgs']]]] = None,
                 unhealthy_threshold: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a HealthCheckTemplate resource.
        :param pulumi.Input[builtins.str] health_check_template_name: 健康检查模板的名称。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点（.）、下划线（_）和短横线（-）。长度限制在1～128字符之间。
        :param pulumi.Input[builtins.str] description: 健康检查描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] health_check_domain: 健康检查的域名。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：需至少包含一个‘.’，且不允许以‘.’开头结尾。单个字符串由字母、数字、‘-’、‘.’字符组成，‘-’不得出现在字符串的头部或尾部。长度限制为1 ～ 128个字符。不填则此参数为空，负载均衡默认使用各后端服务器的私网IP地址进行健康检查。
        :param pulumi.Input[builtins.str] health_check_http_code: 健康检查正常的HTTP状态码。多个状态码用以半角逗号分隔，只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：http*2xx（默认）。http*3xx（默认） 。http*4xx 。http*5xx 。
        :param pulumi.Input[builtins.str] health_check_http_version: 健康检查HTTP协议版本。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：HTTP1.0（默认值）。HTTP1.1。
        :param pulumi.Input[builtins.int] health_check_interval: 执行健康检查的时间间隔，默认为2，取值1-300s 。
        :param pulumi.Input[builtins.str] health_check_method: 健康检查的方法。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：GETHEAD（默认方法）
        :param pulumi.Input[builtins.int] health_check_port: 健康检查端口。取值如下：0：使用后端服务器端口进行健康检查。1-65535：使用您指定的端口进行健康检查。
        :param pulumi.Input[builtins.str] health_check_protocol: 健康检查的协议。HTTPTCP。
        :param pulumi.Input[builtins.int] health_check_timeout: 健康检查的响应超时时间，默认为2，取值1-60s 。
        :param pulumi.Input[builtins.str] health_check_uri: 健康检查的路径。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：必须以字符‘/’开头。仅包含字母、数字、‘-’、‘_’、‘/’、‘.’、‘%’、‘?’、‘#’、‘&’、‘＝’字符。长度限制为1 ～ 128个字符。不填默认为“/”。
        :param pulumi.Input[builtins.int] healthy_threshold: 健康检查的健康阈值，默认为3，取值2-10次。
        :param pulumi.Input[builtins.str] project_name: 健康检查模板所属项目名称。
        :param pulumi.Input[builtins.int] unhealthy_threshold: 健康检查的不健康阈值，默认为3，取值2-10次。
        """
        pulumi.set(__self__, "health_check_template_name", health_check_template_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if health_check_domain is not None:
            pulumi.set(__self__, "health_check_domain", health_check_domain)
        if health_check_http_code is not None:
            pulumi.set(__self__, "health_check_http_code", health_check_http_code)
        if health_check_http_version is not None:
            pulumi.set(__self__, "health_check_http_version", health_check_http_version)
        if health_check_interval is not None:
            pulumi.set(__self__, "health_check_interval", health_check_interval)
        if health_check_method is not None:
            pulumi.set(__self__, "health_check_method", health_check_method)
        if health_check_port is not None:
            pulumi.set(__self__, "health_check_port", health_check_port)
        if health_check_protocol is not None:
            pulumi.set(__self__, "health_check_protocol", health_check_protocol)
        if health_check_timeout is not None:
            pulumi.set(__self__, "health_check_timeout", health_check_timeout)
        if health_check_uri is not None:
            pulumi.set(__self__, "health_check_uri", health_check_uri)
        if healthy_threshold is not None:
            pulumi.set(__self__, "healthy_threshold", healthy_threshold)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if unhealthy_threshold is not None:
            pulumi.set(__self__, "unhealthy_threshold", unhealthy_threshold)

    @property
    @pulumi.getter(name="healthCheckTemplateName")
    def health_check_template_name(self) -> pulumi.Input[builtins.str]:
        """
        健康检查模板的名称。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点（.）、下划线（_）和短横线（-）。长度限制在1～128字符之间。
        """
        return pulumi.get(self, "health_check_template_name")

    @health_check_template_name.setter
    def health_check_template_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "health_check_template_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthCheckDomain")
    def health_check_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查的域名。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：需至少包含一个‘.’，且不允许以‘.’开头结尾。单个字符串由字母、数字、‘-’、‘.’字符组成，‘-’不得出现在字符串的头部或尾部。长度限制为1 ～ 128个字符。不填则此参数为空，负载均衡默认使用各后端服务器的私网IP地址进行健康检查。
        """
        return pulumi.get(self, "health_check_domain")

    @health_check_domain.setter
    def health_check_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_domain", value)

    @property
    @pulumi.getter(name="healthCheckHttpCode")
    def health_check_http_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查正常的HTTP状态码。多个状态码用以半角逗号分隔，只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：http*2xx（默认）。http*3xx（默认） 。http*4xx 。http*5xx 。
        """
        return pulumi.get(self, "health_check_http_code")

    @health_check_http_code.setter
    def health_check_http_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_http_code", value)

    @property
    @pulumi.getter(name="healthCheckHttpVersion")
    def health_check_http_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查HTTP协议版本。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：HTTP1.0（默认值）。HTTP1.1。
        """
        return pulumi.get(self, "health_check_http_version")

    @health_check_http_version.setter
    def health_check_http_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_http_version", value)

    @property
    @pulumi.getter(name="healthCheckInterval")
    def health_check_interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        执行健康检查的时间间隔，默认为2，取值1-300s 。
        """
        return pulumi.get(self, "health_check_interval")

    @health_check_interval.setter
    def health_check_interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "health_check_interval", value)

    @property
    @pulumi.getter(name="healthCheckMethod")
    def health_check_method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查的方法。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：GETHEAD（默认方法）
        """
        return pulumi.get(self, "health_check_method")

    @health_check_method.setter
    def health_check_method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_method", value)

    @property
    @pulumi.getter(name="healthCheckPort")
    def health_check_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        健康检查端口。取值如下：0：使用后端服务器端口进行健康检查。1-65535：使用您指定的端口进行健康检查。
        """
        return pulumi.get(self, "health_check_port")

    @health_check_port.setter
    def health_check_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "health_check_port", value)

    @property
    @pulumi.getter(name="healthCheckProtocol")
    def health_check_protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查的协议。HTTPTCP。
        """
        return pulumi.get(self, "health_check_protocol")

    @health_check_protocol.setter
    def health_check_protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_protocol", value)

    @property
    @pulumi.getter(name="healthCheckTimeout")
    def health_check_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        健康检查的响应超时时间，默认为2，取值1-60s 。
        """
        return pulumi.get(self, "health_check_timeout")

    @health_check_timeout.setter
    def health_check_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "health_check_timeout", value)

    @property
    @pulumi.getter(name="healthCheckUri")
    def health_check_uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查的路径。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：必须以字符‘/’开头。仅包含字母、数字、‘-’、‘_’、‘/’、‘.’、‘%’、‘?’、‘#’、‘&’、‘＝’字符。长度限制为1 ～ 128个字符。不填默认为“/”。
        """
        return pulumi.get(self, "health_check_uri")

    @health_check_uri.setter
    def health_check_uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_uri", value)

    @property
    @pulumi.getter(name="healthyThreshold")
    def healthy_threshold(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        健康检查的健康阈值，默认为3，取值2-10次。
        """
        return pulumi.get(self, "healthy_threshold")

    @healthy_threshold.setter
    def healthy_threshold(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "healthy_threshold", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查模板所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['HealthCheckTemplateTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['HealthCheckTemplateTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="unhealthyThreshold")
    def unhealthy_threshold(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        健康检查的不健康阈值，默认为3，取值2-10次。
        """
        return pulumi.get(self, "unhealthy_threshold")

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "unhealthy_threshold", value)


@pulumi.input_type
class _HealthCheckTemplateState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_domain: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_http_code: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_http_version: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_interval: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_method: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_port: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_protocol: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_template_name: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_uri: Optional[pulumi.Input[builtins.str]] = None,
                 healthy_threshold: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['HealthCheckTemplateTagArgs']]]] = None,
                 unhealthy_threshold: Optional[pulumi.Input[builtins.int]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering HealthCheckTemplate resources.
        :param pulumi.Input[builtins.str] create_time: 健康检查模版的创建时间。
        :param pulumi.Input[builtins.str] description: 健康检查描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] health_check_domain: 健康检查的域名。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：需至少包含一个‘.’，且不允许以‘.’开头结尾。单个字符串由字母、数字、‘-’、‘.’字符组成，‘-’不得出现在字符串的头部或尾部。长度限制为1 ～ 128个字符。不填则此参数为空，负载均衡默认使用各后端服务器的私网IP地址进行健康检查。
        :param pulumi.Input[builtins.str] health_check_http_code: 健康检查正常的HTTP状态码。多个状态码用以半角逗号分隔，只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：http*2xx（默认）。http*3xx（默认） 。http*4xx 。http*5xx 。
        :param pulumi.Input[builtins.str] health_check_http_version: 健康检查HTTP协议版本。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：HTTP1.0（默认值）。HTTP1.1。
        :param pulumi.Input[builtins.int] health_check_interval: 执行健康检查的时间间隔，默认为2，取值1-300s 。
        :param pulumi.Input[builtins.str] health_check_method: 健康检查的方法。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：GETHEAD（默认方法）
        :param pulumi.Input[builtins.int] health_check_port: 健康检查端口。取值如下：0：使用后端服务器端口进行健康检查。1-65535：使用您指定的端口进行健康检查。
        :param pulumi.Input[builtins.str] health_check_protocol: 健康检查的协议。HTTPTCP。
        :param pulumi.Input[builtins.str] health_check_template_id: 健康检查模板 ID。
        :param pulumi.Input[builtins.str] health_check_template_name: 健康检查模板的名称。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点（.）、下划线（_）和短横线（-）。长度限制在1～128字符之间。
        :param pulumi.Input[builtins.int] health_check_timeout: 健康检查的响应超时时间，默认为2，取值1-60s 。
        :param pulumi.Input[builtins.str] health_check_uri: 健康检查的路径。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：必须以字符‘/’开头。仅包含字母、数字、‘-’、‘_’、‘/’、‘.’、‘%’、‘?’、‘#’、‘&’、‘＝’字符。长度限制为1 ～ 128个字符。不填默认为“/”。
        :param pulumi.Input[builtins.int] healthy_threshold: 健康检查的健康阈值，默认为3，取值2-10次。
        :param pulumi.Input[builtins.str] project_name: 健康检查模板所属项目名称。
        :param pulumi.Input[builtins.int] unhealthy_threshold: 健康检查的不健康阈值，默认为3，取值2-10次。
        :param pulumi.Input[builtins.str] update_time: 健康检查模版最近一次的操作时间。
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if health_check_domain is not None:
            pulumi.set(__self__, "health_check_domain", health_check_domain)
        if health_check_http_code is not None:
            pulumi.set(__self__, "health_check_http_code", health_check_http_code)
        if health_check_http_version is not None:
            pulumi.set(__self__, "health_check_http_version", health_check_http_version)
        if health_check_interval is not None:
            pulumi.set(__self__, "health_check_interval", health_check_interval)
        if health_check_method is not None:
            pulumi.set(__self__, "health_check_method", health_check_method)
        if health_check_port is not None:
            pulumi.set(__self__, "health_check_port", health_check_port)
        if health_check_protocol is not None:
            pulumi.set(__self__, "health_check_protocol", health_check_protocol)
        if health_check_template_id is not None:
            pulumi.set(__self__, "health_check_template_id", health_check_template_id)
        if health_check_template_name is not None:
            pulumi.set(__self__, "health_check_template_name", health_check_template_name)
        if health_check_timeout is not None:
            pulumi.set(__self__, "health_check_timeout", health_check_timeout)
        if health_check_uri is not None:
            pulumi.set(__self__, "health_check_uri", health_check_uri)
        if healthy_threshold is not None:
            pulumi.set(__self__, "healthy_threshold", healthy_threshold)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if unhealthy_threshold is not None:
            pulumi.set(__self__, "unhealthy_threshold", unhealthy_threshold)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查模版的创建时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthCheckDomain")
    def health_check_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查的域名。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：需至少包含一个‘.’，且不允许以‘.’开头结尾。单个字符串由字母、数字、‘-’、‘.’字符组成，‘-’不得出现在字符串的头部或尾部。长度限制为1 ～ 128个字符。不填则此参数为空，负载均衡默认使用各后端服务器的私网IP地址进行健康检查。
        """
        return pulumi.get(self, "health_check_domain")

    @health_check_domain.setter
    def health_check_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_domain", value)

    @property
    @pulumi.getter(name="healthCheckHttpCode")
    def health_check_http_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查正常的HTTP状态码。多个状态码用以半角逗号分隔，只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：http*2xx（默认）。http*3xx（默认） 。http*4xx 。http*5xx 。
        """
        return pulumi.get(self, "health_check_http_code")

    @health_check_http_code.setter
    def health_check_http_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_http_code", value)

    @property
    @pulumi.getter(name="healthCheckHttpVersion")
    def health_check_http_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查HTTP协议版本。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：HTTP1.0（默认值）。HTTP1.1。
        """
        return pulumi.get(self, "health_check_http_version")

    @health_check_http_version.setter
    def health_check_http_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_http_version", value)

    @property
    @pulumi.getter(name="healthCheckInterval")
    def health_check_interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        执行健康检查的时间间隔，默认为2，取值1-300s 。
        """
        return pulumi.get(self, "health_check_interval")

    @health_check_interval.setter
    def health_check_interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "health_check_interval", value)

    @property
    @pulumi.getter(name="healthCheckMethod")
    def health_check_method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查的方法。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：GETHEAD（默认方法）
        """
        return pulumi.get(self, "health_check_method")

    @health_check_method.setter
    def health_check_method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_method", value)

    @property
    @pulumi.getter(name="healthCheckPort")
    def health_check_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        健康检查端口。取值如下：0：使用后端服务器端口进行健康检查。1-65535：使用您指定的端口进行健康检查。
        """
        return pulumi.get(self, "health_check_port")

    @health_check_port.setter
    def health_check_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "health_check_port", value)

    @property
    @pulumi.getter(name="healthCheckProtocol")
    def health_check_protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查的协议。HTTPTCP。
        """
        return pulumi.get(self, "health_check_protocol")

    @health_check_protocol.setter
    def health_check_protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_protocol", value)

    @property
    @pulumi.getter(name="healthCheckTemplateId")
    def health_check_template_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查模板 ID。
        """
        return pulumi.get(self, "health_check_template_id")

    @health_check_template_id.setter
    def health_check_template_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_template_id", value)

    @property
    @pulumi.getter(name="healthCheckTemplateName")
    def health_check_template_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查模板的名称。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点（.）、下划线（_）和短横线（-）。长度限制在1～128字符之间。
        """
        return pulumi.get(self, "health_check_template_name")

    @health_check_template_name.setter
    def health_check_template_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_template_name", value)

    @property
    @pulumi.getter(name="healthCheckTimeout")
    def health_check_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        健康检查的响应超时时间，默认为2，取值1-60s 。
        """
        return pulumi.get(self, "health_check_timeout")

    @health_check_timeout.setter
    def health_check_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "health_check_timeout", value)

    @property
    @pulumi.getter(name="healthCheckUri")
    def health_check_uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查的路径。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：必须以字符‘/’开头。仅包含字母、数字、‘-’、‘_’、‘/’、‘.’、‘%’、‘?’、‘#’、‘&’、‘＝’字符。长度限制为1 ～ 128个字符。不填默认为“/”。
        """
        return pulumi.get(self, "health_check_uri")

    @health_check_uri.setter
    def health_check_uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "health_check_uri", value)

    @property
    @pulumi.getter(name="healthyThreshold")
    def healthy_threshold(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        健康检查的健康阈值，默认为3，取值2-10次。
        """
        return pulumi.get(self, "healthy_threshold")

    @healthy_threshold.setter
    def healthy_threshold(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "healthy_threshold", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查模板所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['HealthCheckTemplateTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['HealthCheckTemplateTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="unhealthyThreshold")
    def unhealthy_threshold(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        健康检查的不健康阈值，默认为3，取值2-10次。
        """
        return pulumi.get(self, "unhealthy_threshold")

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "unhealthy_threshold", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        健康检查模版最近一次的操作时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("bytepluscc:alb/healthCheckTemplate:HealthCheckTemplate")
class HealthCheckTemplate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_domain: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_http_code: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_http_version: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_interval: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_method: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_port: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_protocol: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_template_name: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_uri: Optional[pulumi.Input[builtins.str]] = None,
                 healthy_threshold: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HealthCheckTemplateTagArgs', 'HealthCheckTemplateTagArgsDict']]]]] = None,
                 unhealthy_threshold: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        健康检查是确保应用程序是否可用的关键功能。ALB 通过定期对后端服务器进行健康检查，来验证这些服务器是否可以接受新的请求。当一个后端服务器不能正常响应 ALB 的健康检查请求时，来自客户端的流量不会被路由到该服务器。ALB 会将流量转发至其他状态为正常的服务器上。从而保证了服务的连续性和可靠性。ALB 健康检查是基于服务器组进行的。服务器组启用健康检查后，ALB 定期检查服务器组内的后端服务器状态。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        a_lb_health_check_template_demo = bytepluscc.alb.HealthCheckTemplate("ALBHealthCheckTemplateDemo",
            description="asdfgh",
            health_check_domain="test.com",
            health_check_http_code="http_2xx,http_3xx",
            health_check_http_version="HTTP1.0",
            health_check_interval=2,
            health_check_method="HEAD",
            health_check_port=0,
            health_check_protocol="HTTP",
            health_check_template_name="test-test-1001",
            health_check_timeout=2,
            health_check_uri="/",
            healthy_threshold=3,
            unhealthy_threshold=3,
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/healthCheckTemplate:HealthCheckTemplate example "health_check_template_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 健康检查描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] health_check_domain: 健康检查的域名。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：需至少包含一个‘.’，且不允许以‘.’开头结尾。单个字符串由字母、数字、‘-’、‘.’字符组成，‘-’不得出现在字符串的头部或尾部。长度限制为1 ～ 128个字符。不填则此参数为空，负载均衡默认使用各后端服务器的私网IP地址进行健康检查。
        :param pulumi.Input[builtins.str] health_check_http_code: 健康检查正常的HTTP状态码。多个状态码用以半角逗号分隔，只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：http*2xx（默认）。http*3xx（默认） 。http*4xx 。http*5xx 。
        :param pulumi.Input[builtins.str] health_check_http_version: 健康检查HTTP协议版本。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：HTTP1.0（默认值）。HTTP1.1。
        :param pulumi.Input[builtins.int] health_check_interval: 执行健康检查的时间间隔，默认为2，取值1-300s 。
        :param pulumi.Input[builtins.str] health_check_method: 健康检查的方法。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：GETHEAD（默认方法）
        :param pulumi.Input[builtins.int] health_check_port: 健康检查端口。取值如下：0：使用后端服务器端口进行健康检查。1-65535：使用您指定的端口进行健康检查。
        :param pulumi.Input[builtins.str] health_check_protocol: 健康检查的协议。HTTPTCP。
        :param pulumi.Input[builtins.str] health_check_template_name: 健康检查模板的名称。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点（.）、下划线（_）和短横线（-）。长度限制在1～128字符之间。
        :param pulumi.Input[builtins.int] health_check_timeout: 健康检查的响应超时时间，默认为2，取值1-60s 。
        :param pulumi.Input[builtins.str] health_check_uri: 健康检查的路径。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：必须以字符‘/’开头。仅包含字母、数字、‘-’、‘_’、‘/’、‘.’、‘%’、‘?’、‘#’、‘&’、‘＝’字符。长度限制为1 ～ 128个字符。不填默认为“/”。
        :param pulumi.Input[builtins.int] healthy_threshold: 健康检查的健康阈值，默认为3，取值2-10次。
        :param pulumi.Input[builtins.str] project_name: 健康检查模板所属项目名称。
        :param pulumi.Input[builtins.int] unhealthy_threshold: 健康检查的不健康阈值，默认为3，取值2-10次。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HealthCheckTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        健康检查是确保应用程序是否可用的关键功能。ALB 通过定期对后端服务器进行健康检查，来验证这些服务器是否可以接受新的请求。当一个后端服务器不能正常响应 ALB 的健康检查请求时，来自客户端的流量不会被路由到该服务器。ALB 会将流量转发至其他状态为正常的服务器上。从而保证了服务的连续性和可靠性。ALB 健康检查是基于服务器组进行的。服务器组启用健康检查后，ALB 定期检查服务器组内的后端服务器状态。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        a_lb_health_check_template_demo = bytepluscc.alb.HealthCheckTemplate("ALBHealthCheckTemplateDemo",
            description="asdfgh",
            health_check_domain="test.com",
            health_check_http_code="http_2xx,http_3xx",
            health_check_http_version="HTTP1.0",
            health_check_interval=2,
            health_check_method="HEAD",
            health_check_port=0,
            health_check_protocol="HTTP",
            health_check_template_name="test-test-1001",
            health_check_timeout=2,
            health_check_uri="/",
            healthy_threshold=3,
            unhealthy_threshold=3,
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/healthCheckTemplate:HealthCheckTemplate example "health_check_template_id"
        ```

        :param str resource_name: The name of the resource.
        :param HealthCheckTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HealthCheckTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_domain: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_http_code: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_http_version: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_interval: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_method: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_port: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_protocol: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_template_name: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 health_check_uri: Optional[pulumi.Input[builtins.str]] = None,
                 healthy_threshold: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HealthCheckTemplateTagArgs', 'HealthCheckTemplateTagArgsDict']]]]] = None,
                 unhealthy_threshold: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HealthCheckTemplateArgs.__new__(HealthCheckTemplateArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["health_check_domain"] = health_check_domain
            __props__.__dict__["health_check_http_code"] = health_check_http_code
            __props__.__dict__["health_check_http_version"] = health_check_http_version
            __props__.__dict__["health_check_interval"] = health_check_interval
            __props__.__dict__["health_check_method"] = health_check_method
            __props__.__dict__["health_check_port"] = health_check_port
            __props__.__dict__["health_check_protocol"] = health_check_protocol
            if health_check_template_name is None and not opts.urn:
                raise TypeError("Missing required property 'health_check_template_name'")
            __props__.__dict__["health_check_template_name"] = health_check_template_name
            __props__.__dict__["health_check_timeout"] = health_check_timeout
            __props__.__dict__["health_check_uri"] = health_check_uri
            __props__.__dict__["healthy_threshold"] = healthy_threshold
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["unhealthy_threshold"] = unhealthy_threshold
            __props__.__dict__["create_time"] = None
            __props__.__dict__["health_check_template_id"] = None
            __props__.__dict__["update_time"] = None
        super(HealthCheckTemplate, __self__).__init__(
            'bytepluscc:alb/healthCheckTemplate:HealthCheckTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            health_check_domain: Optional[pulumi.Input[builtins.str]] = None,
            health_check_http_code: Optional[pulumi.Input[builtins.str]] = None,
            health_check_http_version: Optional[pulumi.Input[builtins.str]] = None,
            health_check_interval: Optional[pulumi.Input[builtins.int]] = None,
            health_check_method: Optional[pulumi.Input[builtins.str]] = None,
            health_check_port: Optional[pulumi.Input[builtins.int]] = None,
            health_check_protocol: Optional[pulumi.Input[builtins.str]] = None,
            health_check_template_id: Optional[pulumi.Input[builtins.str]] = None,
            health_check_template_name: Optional[pulumi.Input[builtins.str]] = None,
            health_check_timeout: Optional[pulumi.Input[builtins.int]] = None,
            health_check_uri: Optional[pulumi.Input[builtins.str]] = None,
            healthy_threshold: Optional[pulumi.Input[builtins.int]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HealthCheckTemplateTagArgs', 'HealthCheckTemplateTagArgsDict']]]]] = None,
            unhealthy_threshold: Optional[pulumi.Input[builtins.int]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None) -> 'HealthCheckTemplate':
        """
        Get an existing HealthCheckTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: 健康检查模版的创建时间。
        :param pulumi.Input[builtins.str] description: 健康检查描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] health_check_domain: 健康检查的域名。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：需至少包含一个‘.’，且不允许以‘.’开头结尾。单个字符串由字母、数字、‘-’、‘.’字符组成，‘-’不得出现在字符串的头部或尾部。长度限制为1 ～ 128个字符。不填则此参数为空，负载均衡默认使用各后端服务器的私网IP地址进行健康检查。
        :param pulumi.Input[builtins.str] health_check_http_code: 健康检查正常的HTTP状态码。多个状态码用以半角逗号分隔，只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：http*2xx（默认）。http*3xx（默认） 。http*4xx 。http*5xx 。
        :param pulumi.Input[builtins.str] health_check_http_version: 健康检查HTTP协议版本。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：HTTP1.0（默认值）。HTTP1.1。
        :param pulumi.Input[builtins.int] health_check_interval: 执行健康检查的时间间隔，默认为2，取值1-300s 。
        :param pulumi.Input[builtins.str] health_check_method: 健康检查的方法。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：GETHEAD（默认方法）
        :param pulumi.Input[builtins.int] health_check_port: 健康检查端口。取值如下：0：使用后端服务器端口进行健康检查。1-65535：使用您指定的端口进行健康检查。
        :param pulumi.Input[builtins.str] health_check_protocol: 健康检查的协议。HTTPTCP。
        :param pulumi.Input[builtins.str] health_check_template_id: 健康检查模板 ID。
        :param pulumi.Input[builtins.str] health_check_template_name: 健康检查模板的名称。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点（.）、下划线（_）和短横线（-）。长度限制在1～128字符之间。
        :param pulumi.Input[builtins.int] health_check_timeout: 健康检查的响应超时时间，默认为2，取值1-60s 。
        :param pulumi.Input[builtins.str] health_check_uri: 健康检查的路径。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：必须以字符‘/’开头。仅包含字母、数字、‘-’、‘_’、‘/’、‘.’、‘%’、‘?’、‘#’、‘&’、‘＝’字符。长度限制为1 ～ 128个字符。不填默认为“/”。
        :param pulumi.Input[builtins.int] healthy_threshold: 健康检查的健康阈值，默认为3，取值2-10次。
        :param pulumi.Input[builtins.str] project_name: 健康检查模板所属项目名称。
        :param pulumi.Input[builtins.int] unhealthy_threshold: 健康检查的不健康阈值，默认为3，取值2-10次。
        :param pulumi.Input[builtins.str] update_time: 健康检查模版最近一次的操作时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HealthCheckTemplateState.__new__(_HealthCheckTemplateState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["health_check_domain"] = health_check_domain
        __props__.__dict__["health_check_http_code"] = health_check_http_code
        __props__.__dict__["health_check_http_version"] = health_check_http_version
        __props__.__dict__["health_check_interval"] = health_check_interval
        __props__.__dict__["health_check_method"] = health_check_method
        __props__.__dict__["health_check_port"] = health_check_port
        __props__.__dict__["health_check_protocol"] = health_check_protocol
        __props__.__dict__["health_check_template_id"] = health_check_template_id
        __props__.__dict__["health_check_template_name"] = health_check_template_name
        __props__.__dict__["health_check_timeout"] = health_check_timeout
        __props__.__dict__["health_check_uri"] = health_check_uri
        __props__.__dict__["healthy_threshold"] = healthy_threshold
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["unhealthy_threshold"] = unhealthy_threshold
        __props__.__dict__["update_time"] = update_time
        return HealthCheckTemplate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        健康检查模版的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        健康检查描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="healthCheckDomain")
    def health_check_domain(self) -> pulumi.Output[builtins.str]:
        """
        健康检查的域名。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：需至少包含一个‘.’，且不允许以‘.’开头结尾。单个字符串由字母、数字、‘-’、‘.’字符组成，‘-’不得出现在字符串的头部或尾部。长度限制为1 ～ 128个字符。不填则此参数为空，负载均衡默认使用各后端服务器的私网IP地址进行健康检查。
        """
        return pulumi.get(self, "health_check_domain")

    @property
    @pulumi.getter(name="healthCheckHttpCode")
    def health_check_http_code(self) -> pulumi.Output[builtins.str]:
        """
        健康检查正常的HTTP状态码。多个状态码用以半角逗号分隔，只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：http*2xx（默认）。http*3xx（默认） 。http*4xx 。http*5xx 。
        """
        return pulumi.get(self, "health_check_http_code")

    @property
    @pulumi.getter(name="healthCheckHttpVersion")
    def health_check_http_version(self) -> pulumi.Output[builtins.str]:
        """
        健康检查HTTP协议版本。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：HTTP1.0（默认值）。HTTP1.1。
        """
        return pulumi.get(self, "health_check_http_version")

    @property
    @pulumi.getter(name="healthCheckInterval")
    def health_check_interval(self) -> pulumi.Output[builtins.int]:
        """
        执行健康检查的时间间隔，默认为2，取值1-300s 。
        """
        return pulumi.get(self, "health_check_interval")

    @property
    @pulumi.getter(name="healthCheckMethod")
    def health_check_method(self) -> pulumi.Output[builtins.str]:
        """
        健康检查的方法。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：GETHEAD（默认方法）
        """
        return pulumi.get(self, "health_check_method")

    @property
    @pulumi.getter(name="healthCheckPort")
    def health_check_port(self) -> pulumi.Output[builtins.int]:
        """
        健康检查端口。取值如下：0：使用后端服务器端口进行健康检查。1-65535：使用您指定的端口进行健康检查。
        """
        return pulumi.get(self, "health_check_port")

    @property
    @pulumi.getter(name="healthCheckProtocol")
    def health_check_protocol(self) -> pulumi.Output[builtins.str]:
        """
        健康检查的协议。HTTPTCP。
        """
        return pulumi.get(self, "health_check_protocol")

    @property
    @pulumi.getter(name="healthCheckTemplateId")
    def health_check_template_id(self) -> pulumi.Output[builtins.str]:
        """
        健康检查模板 ID。
        """
        return pulumi.get(self, "health_check_template_id")

    @property
    @pulumi.getter(name="healthCheckTemplateName")
    def health_check_template_name(self) -> pulumi.Output[builtins.str]:
        """
        健康检查模板的名称。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点（.）、下划线（_）和短横线（-）。长度限制在1～128字符之间。
        """
        return pulumi.get(self, "health_check_template_name")

    @property
    @pulumi.getter(name="healthCheckTimeout")
    def health_check_timeout(self) -> pulumi.Output[builtins.int]:
        """
        健康检查的响应超时时间，默认为2，取值1-60s 。
        """
        return pulumi.get(self, "health_check_timeout")

    @property
    @pulumi.getter(name="healthCheckUri")
    def health_check_uri(self) -> pulumi.Output[builtins.str]:
        """
        健康检查的路径。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：必须以字符‘/’开头。仅包含字母、数字、‘-’、‘_’、‘/’、‘.’、‘%’、‘?’、‘#’、‘&’、‘＝’字符。长度限制为1 ～ 128个字符。不填默认为“/”。
        """
        return pulumi.get(self, "health_check_uri")

    @property
    @pulumi.getter(name="healthyThreshold")
    def healthy_threshold(self) -> pulumi.Output[builtins.int]:
        """
        健康检查的健康阈值，默认为3，取值2-10次。
        """
        return pulumi.get(self, "healthy_threshold")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        健康检查模板所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.HealthCheckTemplateTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="unhealthyThreshold")
    def unhealthy_threshold(self) -> pulumi.Output[builtins.int]:
        """
        健康检查的不健康阈值，默认为3，取值2-10次。
        """
        return pulumi.get(self, "unhealthy_threshold")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        健康检查模版最近一次的操作时间。
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDeploymentSetResult',
    'AwaitableGetDeploymentSetResult',
    'get_deployment_set',
    'get_deployment_set_output',
]

@pulumi.output_type
class GetDeploymentSetResult:
    """
    A collection of values returned by getDeploymentSet.
    """
    def __init__(__self__, capacities=None, created_at=None, deployment_set_group_number=None, deployment_set_id=None, deployment_set_name=None, description=None, granularity=None, group_count=None, id=None, instance_amount=None, instance_ids=None, strategy=None):
        if capacities and not isinstance(capacities, list):
            raise TypeError("Expected argument 'capacities' to be a list")
        pulumi.set(__self__, "capacities", capacities)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if deployment_set_group_number and not isinstance(deployment_set_group_number, int):
            raise TypeError("Expected argument 'deployment_set_group_number' to be a int")
        pulumi.set(__self__, "deployment_set_group_number", deployment_set_group_number)
        if deployment_set_id and not isinstance(deployment_set_id, str):
            raise TypeError("Expected argument 'deployment_set_id' to be a str")
        pulumi.set(__self__, "deployment_set_id", deployment_set_id)
        if deployment_set_name and not isinstance(deployment_set_name, str):
            raise TypeError("Expected argument 'deployment_set_name' to be a str")
        pulumi.set(__self__, "deployment_set_name", deployment_set_name)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if granularity and not isinstance(granularity, str):
            raise TypeError("Expected argument 'granularity' to be a str")
        pulumi.set(__self__, "granularity", granularity)
        if group_count and not isinstance(group_count, int):
            raise TypeError("Expected argument 'group_count' to be a int")
        pulumi.set(__self__, "group_count", group_count)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_amount and not isinstance(instance_amount, int):
            raise TypeError("Expected argument 'instance_amount' to be a int")
        pulumi.set(__self__, "instance_amount", instance_amount)
        if instance_ids and not isinstance(instance_ids, list):
            raise TypeError("Expected argument 'instance_ids' to be a list")
        pulumi.set(__self__, "instance_ids", instance_ids)
        if strategy and not isinstance(strategy, str):
            raise TypeError("Expected argument 'strategy' to be a str")
        pulumi.set(__self__, "strategy", strategy)

    @property
    @pulumi.getter
    def capacities(self) -> Sequence['outputs.GetDeploymentSetCapacityResult']:
        """
        实例启动模板版本信息。
        """
        return pulumi.get(self, "capacities")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        部署集的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> builtins.int:
        """
        部署集组的序号，取值范围：1～7。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> builtins.str:
        """
        部署集ID。
        """
        return pulumi.get(self, "deployment_set_id")

    @property
    @pulumi.getter(name="deploymentSetName")
    def deployment_set_name(self) -> builtins.str:
        """
        部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        """
        return pulumi.get(self, "deployment_set_name")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def granularity(self) -> builtins.str:
        """
        部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        """
        return pulumi.get(self, "granularity")

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> builtins.int:
        """
        部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        """
        return pulumi.get(self, "group_count")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceAmount")
    def instance_amount(self) -> builtins.int:
        """
        部署集内的ECS实例数量。
        """
        return pulumi.get(self, "instance_amount")

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Sequence[builtins.str]:
        """
        部署集内的ECS实例ID列表。
        """
        return pulumi.get(self, "instance_ids")

    @property
    @pulumi.getter
    def strategy(self) -> builtins.str:
        """
        部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        return pulumi.get(self, "strategy")


class AwaitableGetDeploymentSetResult(GetDeploymentSetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDeploymentSetResult(
            capacities=self.capacities,
            created_at=self.created_at,
            deployment_set_group_number=self.deployment_set_group_number,
            deployment_set_id=self.deployment_set_id,
            deployment_set_name=self.deployment_set_name,
            description=self.description,
            granularity=self.granularity,
            group_count=self.group_count,
            id=self.id,
            instance_amount=self.instance_amount,
            instance_ids=self.instance_ids,
            strategy=self.strategy)


def get_deployment_set(id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDeploymentSetResult:
    """
    Data Source schema for Byteplus::ECS::DeploymentSet


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:ecs/getDeploymentSet:getDeploymentSet', __args__, opts=opts, typ=GetDeploymentSetResult).value

    return AwaitableGetDeploymentSetResult(
        capacities=pulumi.get(__ret__, 'capacities'),
        created_at=pulumi.get(__ret__, 'created_at'),
        deployment_set_group_number=pulumi.get(__ret__, 'deployment_set_group_number'),
        deployment_set_id=pulumi.get(__ret__, 'deployment_set_id'),
        deployment_set_name=pulumi.get(__ret__, 'deployment_set_name'),
        description=pulumi.get(__ret__, 'description'),
        granularity=pulumi.get(__ret__, 'granularity'),
        group_count=pulumi.get(__ret__, 'group_count'),
        id=pulumi.get(__ret__, 'id'),
        instance_amount=pulumi.get(__ret__, 'instance_amount'),
        instance_ids=pulumi.get(__ret__, 'instance_ids'),
        strategy=pulumi.get(__ret__, 'strategy'))
def get_deployment_set_output(id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDeploymentSetResult]:
    """
    Data Source schema for Byteplus::ECS::DeploymentSet


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:ecs/getDeploymentSet:getDeploymentSet', __args__, opts=opts, typ=GetDeploymentSetResult)
    return __ret__.apply(lambda __response__: GetDeploymentSetResult(
        capacities=pulumi.get(__response__, 'capacities'),
        created_at=pulumi.get(__response__, 'created_at'),
        deployment_set_group_number=pulumi.get(__response__, 'deployment_set_group_number'),
        deployment_set_id=pulumi.get(__response__, 'deployment_set_id'),
        deployment_set_name=pulumi.get(__response__, 'deployment_set_name'),
        description=pulumi.get(__response__, 'description'),
        granularity=pulumi.get(__response__, 'granularity'),
        group_count=pulumi.get(__response__, 'group_count'),
        id=pulumi.get(__response__, 'id'),
        instance_amount=pulumi.get(__response__, 'instance_amount'),
        instance_ids=pulumi.get(__response__, 'instance_ids'),
        strategy=pulumi.get(__response__, 'strategy')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetHealthCheckTemplateResult',
    'AwaitableGetHealthCheckTemplateResult',
    'get_health_check_template',
    'get_health_check_template_output',
]

@pulumi.output_type
class GetHealthCheckTemplateResult:
    """
    A collection of values returned by getHealthCheckTemplate.
    """
    def __init__(__self__, create_time=None, description=None, health_check_domain=None, health_check_http_code=None, health_check_http_version=None, health_check_interval=None, health_check_method=None, health_check_port=None, health_check_protocol=None, health_check_template_id=None, health_check_template_name=None, health_check_timeout=None, health_check_uri=None, healthy_threshold=None, id=None, project_name=None, tags=None, unhealthy_threshold=None, update_time=None):
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if health_check_domain and not isinstance(health_check_domain, str):
            raise TypeError("Expected argument 'health_check_domain' to be a str")
        pulumi.set(__self__, "health_check_domain", health_check_domain)
        if health_check_http_code and not isinstance(health_check_http_code, str):
            raise TypeError("Expected argument 'health_check_http_code' to be a str")
        pulumi.set(__self__, "health_check_http_code", health_check_http_code)
        if health_check_http_version and not isinstance(health_check_http_version, str):
            raise TypeError("Expected argument 'health_check_http_version' to be a str")
        pulumi.set(__self__, "health_check_http_version", health_check_http_version)
        if health_check_interval and not isinstance(health_check_interval, int):
            raise TypeError("Expected argument 'health_check_interval' to be a int")
        pulumi.set(__self__, "health_check_interval", health_check_interval)
        if health_check_method and not isinstance(health_check_method, str):
            raise TypeError("Expected argument 'health_check_method' to be a str")
        pulumi.set(__self__, "health_check_method", health_check_method)
        if health_check_port and not isinstance(health_check_port, int):
            raise TypeError("Expected argument 'health_check_port' to be a int")
        pulumi.set(__self__, "health_check_port", health_check_port)
        if health_check_protocol and not isinstance(health_check_protocol, str):
            raise TypeError("Expected argument 'health_check_protocol' to be a str")
        pulumi.set(__self__, "health_check_protocol", health_check_protocol)
        if health_check_template_id and not isinstance(health_check_template_id, str):
            raise TypeError("Expected argument 'health_check_template_id' to be a str")
        pulumi.set(__self__, "health_check_template_id", health_check_template_id)
        if health_check_template_name and not isinstance(health_check_template_name, str):
            raise TypeError("Expected argument 'health_check_template_name' to be a str")
        pulumi.set(__self__, "health_check_template_name", health_check_template_name)
        if health_check_timeout and not isinstance(health_check_timeout, int):
            raise TypeError("Expected argument 'health_check_timeout' to be a int")
        pulumi.set(__self__, "health_check_timeout", health_check_timeout)
        if health_check_uri and not isinstance(health_check_uri, str):
            raise TypeError("Expected argument 'health_check_uri' to be a str")
        pulumi.set(__self__, "health_check_uri", health_check_uri)
        if healthy_threshold and not isinstance(healthy_threshold, int):
            raise TypeError("Expected argument 'healthy_threshold' to be a int")
        pulumi.set(__self__, "healthy_threshold", healthy_threshold)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if unhealthy_threshold and not isinstance(unhealthy_threshold, int):
            raise TypeError("Expected argument 'unhealthy_threshold' to be a int")
        pulumi.set(__self__, "unhealthy_threshold", unhealthy_threshold)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        健康检查模版的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        健康检查描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="healthCheckDomain")
    def health_check_domain(self) -> builtins.str:
        """
        健康检查的域名。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：需至少包含一个‘.’，且不允许以‘.’开头结尾。单个字符串由字母、数字、‘-’、‘.’字符组成，‘-’不得出现在字符串的头部或尾部。长度限制为1 ～ 128个字符。不填则此参数为空，负载均衡默认使用各后端服务器的私网IP地址进行健康检查。
        """
        return pulumi.get(self, "health_check_domain")

    @property
    @pulumi.getter(name="healthCheckHttpCode")
    def health_check_http_code(self) -> builtins.str:
        """
        健康检查正常的HTTP状态码。多个状态码用以半角逗号分隔，只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：http*2xx（默认）。http*3xx（默认） 。http*4xx 。http*5xx 。
        """
        return pulumi.get(self, "health_check_http_code")

    @property
    @pulumi.getter(name="healthCheckHttpVersion")
    def health_check_http_version(self) -> builtins.str:
        """
        健康检查HTTP协议版本。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：HTTP1.0（默认值）。HTTP1.1。
        """
        return pulumi.get(self, "health_check_http_version")

    @property
    @pulumi.getter(name="healthCheckInterval")
    def health_check_interval(self) -> builtins.int:
        """
        执行健康检查的时间间隔，默认为2，取值1-300s 。
        """
        return pulumi.get(self, "health_check_interval")

    @property
    @pulumi.getter(name="healthCheckMethod")
    def health_check_method(self) -> builtins.str:
        """
        健康检查的方法。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。取值如下：GETHEAD（默认方法）
        """
        return pulumi.get(self, "health_check_method")

    @property
    @pulumi.getter(name="healthCheckPort")
    def health_check_port(self) -> builtins.int:
        """
        健康检查端口。取值如下：0：使用后端服务器端口进行健康检查。1-65535：使用您指定的端口进行健康检查。
        """
        return pulumi.get(self, "health_check_port")

    @property
    @pulumi.getter(name="healthCheckProtocol")
    def health_check_protocol(self) -> builtins.str:
        """
        健康检查的协议。HTTPTCP。
        """
        return pulumi.get(self, "health_check_protocol")

    @property
    @pulumi.getter(name="healthCheckTemplateId")
    def health_check_template_id(self) -> builtins.str:
        """
        健康检查模板 ID。
        """
        return pulumi.get(self, "health_check_template_id")

    @property
    @pulumi.getter(name="healthCheckTemplateName")
    def health_check_template_name(self) -> builtins.str:
        """
        健康检查模板的名称。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点（.）、下划线（_）和短横线（-）。长度限制在1～128字符之间。
        """
        return pulumi.get(self, "health_check_template_name")

    @property
    @pulumi.getter(name="healthCheckTimeout")
    def health_check_timeout(self) -> builtins.int:
        """
        健康检查的响应超时时间，默认为2，取值1-60s 。
        """
        return pulumi.get(self, "health_check_timeout")

    @property
    @pulumi.getter(name="healthCheckUri")
    def health_check_uri(self) -> builtins.str:
        """
        健康检查的路径。只有 HealthCheckProtocol 设置为 HTTP 时，该参数才生效。要求如下：必须以字符‘/’开头。仅包含字母、数字、‘-’、‘_’、‘/’、‘.’、‘%’、‘?’、‘#’、‘&’、‘＝’字符。长度限制为1 ～ 128个字符。不填默认为“/”。
        """
        return pulumi.get(self, "health_check_uri")

    @property
    @pulumi.getter(name="healthyThreshold")
    def healthy_threshold(self) -> builtins.int:
        """
        健康检查的健康阈值，默认为3，取值2-10次。
        """
        return pulumi.get(self, "healthy_threshold")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        健康检查模板所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetHealthCheckTemplateTagResult']:
        """
        健康检查模板关联的标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="unhealthyThreshold")
    def unhealthy_threshold(self) -> builtins.int:
        """
        健康检查的不健康阈值，默认为3，取值2-10次。
        """
        return pulumi.get(self, "unhealthy_threshold")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        健康检查模版最近一次的操作时间。
        """
        return pulumi.get(self, "update_time")


class AwaitableGetHealthCheckTemplateResult(GetHealthCheckTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetHealthCheckTemplateResult(
            create_time=self.create_time,
            description=self.description,
            health_check_domain=self.health_check_domain,
            health_check_http_code=self.health_check_http_code,
            health_check_http_version=self.health_check_http_version,
            health_check_interval=self.health_check_interval,
            health_check_method=self.health_check_method,
            health_check_port=self.health_check_port,
            health_check_protocol=self.health_check_protocol,
            health_check_template_id=self.health_check_template_id,
            health_check_template_name=self.health_check_template_name,
            health_check_timeout=self.health_check_timeout,
            health_check_uri=self.health_check_uri,
            healthy_threshold=self.healthy_threshold,
            id=self.id,
            project_name=self.project_name,
            tags=self.tags,
            unhealthy_threshold=self.unhealthy_threshold,
            update_time=self.update_time)


def get_health_check_template(id: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetHealthCheckTemplateResult:
    """
    Data Source schema for Byteplus::ALB::HealthCheckTemplate


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:alb/getHealthCheckTemplate:getHealthCheckTemplate', __args__, opts=opts, typ=GetHealthCheckTemplateResult).value

    return AwaitableGetHealthCheckTemplateResult(
        create_time=pulumi.get(__ret__, 'create_time'),
        description=pulumi.get(__ret__, 'description'),
        health_check_domain=pulumi.get(__ret__, 'health_check_domain'),
        health_check_http_code=pulumi.get(__ret__, 'health_check_http_code'),
        health_check_http_version=pulumi.get(__ret__, 'health_check_http_version'),
        health_check_interval=pulumi.get(__ret__, 'health_check_interval'),
        health_check_method=pulumi.get(__ret__, 'health_check_method'),
        health_check_port=pulumi.get(__ret__, 'health_check_port'),
        health_check_protocol=pulumi.get(__ret__, 'health_check_protocol'),
        health_check_template_id=pulumi.get(__ret__, 'health_check_template_id'),
        health_check_template_name=pulumi.get(__ret__, 'health_check_template_name'),
        health_check_timeout=pulumi.get(__ret__, 'health_check_timeout'),
        health_check_uri=pulumi.get(__ret__, 'health_check_uri'),
        healthy_threshold=pulumi.get(__ret__, 'healthy_threshold'),
        id=pulumi.get(__ret__, 'id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        tags=pulumi.get(__ret__, 'tags'),
        unhealthy_threshold=pulumi.get(__ret__, 'unhealthy_threshold'),
        update_time=pulumi.get(__ret__, 'update_time'))
def get_health_check_template_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetHealthCheckTemplateResult]:
    """
    Data Source schema for Byteplus::ALB::HealthCheckTemplate


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:alb/getHealthCheckTemplate:getHealthCheckTemplate', __args__, opts=opts, typ=GetHealthCheckTemplateResult)
    return __ret__.apply(lambda __response__: GetHealthCheckTemplateResult(
        create_time=pulumi.get(__response__, 'create_time'),
        description=pulumi.get(__response__, 'description'),
        health_check_domain=pulumi.get(__response__, 'health_check_domain'),
        health_check_http_code=pulumi.get(__response__, 'health_check_http_code'),
        health_check_http_version=pulumi.get(__response__, 'health_check_http_version'),
        health_check_interval=pulumi.get(__response__, 'health_check_interval'),
        health_check_method=pulumi.get(__response__, 'health_check_method'),
        health_check_port=pulumi.get(__response__, 'health_check_port'),
        health_check_protocol=pulumi.get(__response__, 'health_check_protocol'),
        health_check_template_id=pulumi.get(__response__, 'health_check_template_id'),
        health_check_template_name=pulumi.get(__response__, 'health_check_template_name'),
        health_check_timeout=pulumi.get(__response__, 'health_check_timeout'),
        health_check_uri=pulumi.get(__response__, 'health_check_uri'),
        healthy_threshold=pulumi.get(__response__, 'healthy_threshold'),
        id=pulumi.get(__response__, 'id'),
        project_name=pulumi.get(__response__, 'project_name'),
        tags=pulumi.get(__response__, 'tags'),
        unhealthy_threshold=pulumi.get(__response__, 'unhealthy_threshold'),
        update_time=pulumi.get(__response__, 'update_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTrafficMirrorSessionResult',
    'AwaitableGetTrafficMirrorSessionResult',
    'get_traffic_mirror_session',
    'get_traffic_mirror_session_output',
]

@pulumi.output_type
class GetTrafficMirrorSessionResult:
    """
    A collection of values returned by getTrafficMirrorSession.
    """
    def __init__(__self__, business_status=None, created_time=None, description=None, id=None, lock_reason=None, network_interface_id=None, packet_length=None, priority=None, project_name=None, status=None, tags=None, traffic_mirror_filter_id=None, traffic_mirror_session_id=None, traffic_mirror_session_name=None, traffic_mirror_source_ids=None, traffic_mirror_target_id=None, virtual_network_id=None):
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lock_reason and not isinstance(lock_reason, str):
            raise TypeError("Expected argument 'lock_reason' to be a str")
        pulumi.set(__self__, "lock_reason", lock_reason)
        if network_interface_id and not isinstance(network_interface_id, str):
            raise TypeError("Expected argument 'network_interface_id' to be a str")
        pulumi.set(__self__, "network_interface_id", network_interface_id)
        if packet_length and not isinstance(packet_length, int):
            raise TypeError("Expected argument 'packet_length' to be a int")
        pulumi.set(__self__, "packet_length", packet_length)
        if priority and not isinstance(priority, int):
            raise TypeError("Expected argument 'priority' to be a int")
        pulumi.set(__self__, "priority", priority)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if traffic_mirror_filter_id and not isinstance(traffic_mirror_filter_id, str):
            raise TypeError("Expected argument 'traffic_mirror_filter_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_filter_id", traffic_mirror_filter_id)
        if traffic_mirror_session_id and not isinstance(traffic_mirror_session_id, str):
            raise TypeError("Expected argument 'traffic_mirror_session_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_session_id", traffic_mirror_session_id)
        if traffic_mirror_session_name and not isinstance(traffic_mirror_session_name, str):
            raise TypeError("Expected argument 'traffic_mirror_session_name' to be a str")
        pulumi.set(__self__, "traffic_mirror_session_name", traffic_mirror_session_name)
        if traffic_mirror_source_ids and not isinstance(traffic_mirror_source_ids, list):
            raise TypeError("Expected argument 'traffic_mirror_source_ids' to be a list")
        pulumi.set(__self__, "traffic_mirror_source_ids", traffic_mirror_source_ids)
        if traffic_mirror_target_id and not isinstance(traffic_mirror_target_id, str):
            raise TypeError("Expected argument 'traffic_mirror_target_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_target_id", traffic_mirror_target_id)
        if virtual_network_id and not isinstance(virtual_network_id, int):
            raise TypeError("Expected argument 'virtual_network_id' to be a int")
        pulumi.set(__self__, "virtual_network_id", virtual_network_id)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        会话计费状态。Normal：正常计费中。  - FinancialLocked：欠费锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        镜像会话实例描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        """
        锁定原因。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> builtins.str:
        """
        镜像源实例ID，当前只支持ECS的主网卡和辅助网卡。
        """
        return pulumi.get(self, "network_interface_id")

    @property
    @pulumi.getter(name="packetLength")
    def packet_length(self) -> builtins.int:
        """
        镜像会话MTU，超过被截断，取值范围：64～9600。
        """
        return pulumi.get(self, "packet_length")

    @property
    @pulumi.getter
    def priority(self) -> builtins.int:
        """
        镜像会话优先级，取值范围1 ～ 32766，同一账户下镜像会话优先级不能重复。
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        所属项目的名称
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        会话状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetTrafficMirrorSessionTagResult']:
        """
        标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> builtins.str:
        """
        筛选条件实例ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @property
    @pulumi.getter(name="trafficMirrorSessionId")
    def traffic_mirror_session_id(self) -> builtins.str:
        """
        镜像会话实例ID。
        """
        return pulumi.get(self, "traffic_mirror_session_id")

    @property
    @pulumi.getter(name="trafficMirrorSessionName")
    def traffic_mirror_session_name(self) -> builtins.str:
        """
        镜像会话名称。
        """
        return pulumi.get(self, "traffic_mirror_session_name")

    @property
    @pulumi.getter(name="trafficMirrorSourceIds")
    def traffic_mirror_source_ids(self) -> Sequence[builtins.str]:
        """
        镜像源实例列表。
        """
        return pulumi.get(self, "traffic_mirror_source_ids")

    @property
    @pulumi.getter(name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> builtins.str:
        """
        镜像目的实例ID。
        """
        return pulumi.get(self, "traffic_mirror_target_id")

    @property
    @pulumi.getter(name="virtualNetworkId")
    def virtual_network_id(self) -> builtins.int:
        """
        镜像会话VNI，取值范围1 ～ 16777215。
        """
        return pulumi.get(self, "virtual_network_id")


class AwaitableGetTrafficMirrorSessionResult(GetTrafficMirrorSessionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrafficMirrorSessionResult(
            business_status=self.business_status,
            created_time=self.created_time,
            description=self.description,
            id=self.id,
            lock_reason=self.lock_reason,
            network_interface_id=self.network_interface_id,
            packet_length=self.packet_length,
            priority=self.priority,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            traffic_mirror_filter_id=self.traffic_mirror_filter_id,
            traffic_mirror_session_id=self.traffic_mirror_session_id,
            traffic_mirror_session_name=self.traffic_mirror_session_name,
            traffic_mirror_source_ids=self.traffic_mirror_source_ids,
            traffic_mirror_target_id=self.traffic_mirror_target_id,
            virtual_network_id=self.virtual_network_id)


def get_traffic_mirror_session(id: Optional[builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrafficMirrorSessionResult:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorSession


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getTrafficMirrorSession:getTrafficMirrorSession', __args__, opts=opts, typ=GetTrafficMirrorSessionResult).value

    return AwaitableGetTrafficMirrorSessionResult(
        business_status=pulumi.get(__ret__, 'business_status'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        lock_reason=pulumi.get(__ret__, 'lock_reason'),
        network_interface_id=pulumi.get(__ret__, 'network_interface_id'),
        packet_length=pulumi.get(__ret__, 'packet_length'),
        priority=pulumi.get(__ret__, 'priority'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        traffic_mirror_filter_id=pulumi.get(__ret__, 'traffic_mirror_filter_id'),
        traffic_mirror_session_id=pulumi.get(__ret__, 'traffic_mirror_session_id'),
        traffic_mirror_session_name=pulumi.get(__ret__, 'traffic_mirror_session_name'),
        traffic_mirror_source_ids=pulumi.get(__ret__, 'traffic_mirror_source_ids'),
        traffic_mirror_target_id=pulumi.get(__ret__, 'traffic_mirror_target_id'),
        virtual_network_id=pulumi.get(__ret__, 'virtual_network_id'))
def get_traffic_mirror_session_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTrafficMirrorSessionResult]:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorSession


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getTrafficMirrorSession:getTrafficMirrorSession', __args__, opts=opts, typ=GetTrafficMirrorSessionResult)
    return __ret__.apply(lambda __response__: GetTrafficMirrorSessionResult(
        business_status=pulumi.get(__response__, 'business_status'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        lock_reason=pulumi.get(__response__, 'lock_reason'),
        network_interface_id=pulumi.get(__response__, 'network_interface_id'),
        packet_length=pulumi.get(__response__, 'packet_length'),
        priority=pulumi.get(__response__, 'priority'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        traffic_mirror_filter_id=pulumi.get(__response__, 'traffic_mirror_filter_id'),
        traffic_mirror_session_id=pulumi.get(__response__, 'traffic_mirror_session_id'),
        traffic_mirror_session_name=pulumi.get(__response__, 'traffic_mirror_session_name'),
        traffic_mirror_source_ids=pulumi.get(__response__, 'traffic_mirror_source_ids'),
        traffic_mirror_target_id=pulumi.get(__response__, 'traffic_mirror_target_id'),
        virtual_network_id=pulumi.get(__response__, 'virtual_network_id')))
